@@ -257,7 +257,7 @@ class ScormXBlock(XBlock):
                 self.publish_grade()
                 context.update({"lesson_score": self.lesson_score})
         elif name in ["cmi.core.score.raw", "cmi.score.raw"] and self.has_score:
-            self.lesson_score = int(data.get("value", 0)) / 100.0
+            self.lesson_score = float(data.get("value", 0)) / 100.0
             self.publish_grade()
             context.update({"lesson_score": self.lesson_score})
         else:
@@ -277,6 +277,12 @@ class ScormXBlock(XBlock):
                 self, "grade", {"value": self.lesson_score, "max_value": self.weight}
             )
 
+    def set_score(self, score):
+        """
+        Utility method used to rescore a problem.
+        """
+        self.lesson_score = score.raw_earned
+
     def max_score(self):
         """
         Return the maximum score possible.
